# Sudoku Stepper

A tool for stepping through and visualising sudoku solving algorithms.

![Animated Playback Demo](https://github.com/dougfinl/sudokustepper/raw/master/screenshots/backtracing-playback.gif)


## License

[GPLv3](https://choosealicense.com/licenses/gpl-3.0)